@@ -1,10 +1,9 @@
 package Dist::Zilla::PluginBundle::AVAR;
-BEGIN {
-  $Dist::Zilla::PluginBundle::AVAR::AUTHORITY = 'cpan:AVAR';
-}
-$Dist::Zilla::PluginBundle::AVAR::VERSION = '0.31';
+our $AUTHORITY = 'cpan:AVAR';
+$Dist::Zilla::PluginBundle::AVAR::VERSION = '0.32';
 use 5.10.0;
 use Moose;
+use experimental 'smartmatch';
 use Moose::Autobox;
 
 with 'Dist::Zilla::Role::PluginBundle';
